import { 
  select, 
  csv, 
  scaleLinear,
  range,
  max,
  min,
  scaleBand,
	axisLeft,
  scaleTime,
  extent,
  axisBottom,
  format
} from 'd3';


const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const xValue = d => d.year;
  const yValue = d => d.running_total;
  const margin = {top: 50, right: 40, bottom: 75, left: 100};
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const yScale = scaleLinear()
  	.domain([0,max(data, yValue)])
  	.range([innerHeight, 0]).nice()
  
  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth]).nice();
  	//.range([innerWidth/data.length/2, innerWidth-innerWidth/data.length/2]);
  
  const g = svg.append('g')
  	.attr('transform',`translate(${margin.left},${margin.top})`);
  
  const xAxis = axisBottom(xScale)
    .tickSize(10)
  	//.tickValues(min(data,xValue),max(data,xValue),3)
    .ticks(d3.timeYear.every(3));
  
  const yAxis = axisLeft(yScale)
    .ticks(Math.round(max(data,yValue)/1000+1))
  	.tickSize(10);
  
  const yAxisG = g.append('g').call(yAxis);

  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform',`translate(0,${innerHeight})`);
    	
  /*
  xAxisG.append('text')
  	.attr('class','axis-label')
  	.attr('y',65)
  	.attr('x',innerWidth/2)
  	.attr('fill','black')
  	.text('Year');
  */
  g.selectAll('rect').data(data)
  	.enter().append('rect')
  		.attr("y", d => yScale(yValue(d)))
			.attr("x", d => xScale(xValue(d)) - (innerWidth/data.length)/3)
			.attr("width", width/data.length-5)
  		.attr('height', d => yScale(0)- yScale(yValue(d)));

  g.append('text')
  	.attr('class','title')
  	.attr('x',innerWidth/4.5)
  	.attr('y',-10)
  	.text('Lego Sets by Year from Rebrickable');
  
  g.append('text')
  	.attr('class','gtid')
  	.attr('x',innerWidth/20*19)
  	.attr('y',innerHeight+65)
  	.text('cyuen32');
};

//Read data
csv('https://vizhub.com/kelvin127/datasets/q3.csv').then(data => {
	//console.log(data);
  data.forEach(d => {
    d.year = new Date(`01/01/${d.year}`);
    d.running_total = +d.running_total
  });
  render(data);
//console.log(range(0,Math.round(max(data,d => d.running_total)/1000+1)*1000,1000));
//console.log(Math.round(max(data,d => d.running_total)/1000+1)*1000);
});